==> api-bridge-nestjs-1.0.4.tgz: package/src/index.ts <==
/*
 * @Description:sdfsdf
 * @Author: huajian
 * @LastEditors: huajian
 * @LastEditTime: 2021-08-03 22:29:13
 */
import fetch from 'node-fetch';
import fs from 'fs';
import ejs from 'ejs';
import spawn from 'cross-spawn';
const path = require('path');
const outputDir = path.resolve(__dirname, '../output/');
const outputJsonFile = outputDir + '/api-json.json';
if (!fs.existsSync(outputDir)) {
  fs.mkdirSync(outputDir);
}

fetch('http://127.0.0.1:7001/api-json')
  .then((res) => res.text())
  .then((body) => {
    fs.writeFileSync(outputJsonFile, body);
    spawn.sync(
      './node_modules/dtsgenerator/bin/dtsgen',
      [outputJsonFile, '-o', outputDir + '/api-bridge.d.ts'],
      { stdio: 'inherit' }
    );

    const contentBuf = fs.readFileSync(outputDir + '/api-bridge.d.ts');
    const content = contentBuf.toString().replace('declare namespace Paths', 'export declare namespace Paths');
    fs.writeFileSync(outputDir + '/api-bridge.d.ts', content);

    const json = JSON.parse(body);
    const paths = Object.keys(json.paths).map((path) => {
      const result = json.paths[path];
      result.path = path;
      result.requestSchema = '';
      result.requestRequired = '';
      result.responseSchema = 'any';

      const operationId = result.post.operationId.replace(/_(.)/, (m:string, m1:string) => {
        return m1.toUpperCase();
      })

      // 验证是否有有参数
      if (result.post.requestBody) {
        result.requestSchema = 'Paths.' + operationId + '.RequestBody';
        result.requestRequired = result.post.requestBody.required ? '' : '?';
      }

      // 验证返回值
      if (result.post.responses) {
        result.responseSchema = 'Paths.' + operationId + '.Responses.$201';
      }
      return result;
    });
    ejs.renderFile(path.resolve(__dirname, '../tpl.ejs'), { paths }, (err, str) => {
      if (err) {
        console.log(err);
        return;
      }
      fs.writeFileSync(outputDir + '/api.ts', str);
    });
  });

==> api-bridge-nestjs-1.0.5.tgz: package/src/index.ts <==
/*
 * @Description:sdfsdf
 * @Author: huajian
 * @LastEditors: huajian
 * @LastEditTime: 2021-08-04 19:45:03
 */
import fetch from 'node-fetch';
import fs from 'fs';
import ejs from 'ejs';
import spawn from 'cross-spawn';
const path = require('path');
const outputDir = process.cwd() + '/src/api';
const outputJsonFile = outputDir + '/api-json.json';
if (!fs.existsSync(outputDir)) {
  fs.mkdirSync(outputDir);
}

fetch('http://127.0.0.1:7001/api-json')
  .then((res) => res.text())
  .then((body) => {
    fs.writeFileSync(outputJsonFile, body);
    spawn.sync(
      './node_modules/dtsgenerator/bin/dtsgen',
      [outputJsonFile, '-o', outputDir + '/api-bridge.d.ts'],
      { stdio: 'inherit' }
    );

    const contentBuf = fs.readFileSync(outputDir + '/api-bridge.d.ts');
    const content = contentBuf.toString().replace('declare namespace Paths', 'export declare namespace Paths');
    fs.writeFileSync(outputDir + '/api-bridge.d.ts', content);

    const json = JSON.parse(body);
    const paths = Object.keys(json.paths).map((path) => {
      const result = json.paths[path];
      result.path = path;
      result.requestSchema = '';
      result.requestRequired = '';
      result.responseSchema = 'any';

      const operationId = result.post.operationId.replace(/_(.)/, (m:string, m1:string) => {
        return m1.toUpperCase();
      })

      // 验证是否有有参数
      if (result.post.requestBody) {
        result.requestSchema = 'Paths.' + operationId + '.RequestBody';
        result.requestRequired = result.post.requestBody.required ? '' : '?';
      }

      // 验证返回值
      if (result.post.responses) {
        result.responseSchema = 'Paths.' + operationId + '.Responses.$201';
      }
      return result;
    });
    ejs.renderFile(path.resolve(__dirname, '../tpl.ejs'), { paths }, (err, str) => {
      if (err) {
        console.log(err);
        return;
      }
      fs.writeFileSync(outputDir + '/api.ts', str);
    });
  });
